==> haskell-tasty-smallcheck-0.8.2-771-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-smallcheck
version:              0.8.2
visibility:           public
id:                   tasty-smallcheck-0.8.2-FeUHkoYmGOLUVLtfNfzs6
key:                  tasty-smallcheck-0.8.2-FeUHkoYmGOLUVLtfNfzs6
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             SmallCheck support for the Tasty test framework.
description:          SmallCheck support for the Tasty test framework.
category:             Testing
abi:                  d421d774ce1380320dd7ad61d46866a4
exposed:              True
exposed-modules:      Test.Tasty.SmallCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-smallcheck-0.8.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-smallcheck-0.8.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-smallcheck-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-smallcheck
hs-libraries:         HStasty-smallcheck-0.8.2-FeUHkoYmGOLUVLtfNfzs6
depends:
    base-4.17.2.1 optparse-applicative-0.18.1.0-AUOg1zQqVBXHiykDTBb1RQ
    smallcheck-1.2.1.1-4MzXb0hWgGQ7sCJRm30u4
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5.2-GNkjiHoVt5N8yPDCzeLpvg

haddock-interfaces:
    /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-smallcheck-0.8.2-775-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-smallcheck
version:              0.8.2
visibility:           public
id:                   tasty-smallcheck-0.8.2-A6yoXPPalmG7qE02oh2ll1
key:                  tasty-smallcheck-0.8.2-A6yoXPPalmG7qE02oh2ll1
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             SmallCheck support for the Tasty test framework.
description:          SmallCheck support for the Tasty test framework.
category:             Testing
abi:                  f803acd0acf9dbe34d837154d44941c4
exposed:              True
exposed-modules:      Test.Tasty.SmallCheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-smallcheck-0.8.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-smallcheck-0.8.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-smallcheck-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-smallcheck
hs-libraries:         HStasty-smallcheck-0.8.2-A6yoXPPalmG7qE02oh2ll1
depends:
    base-4.17.2.1 optparse-applicative-0.18.1.0-F3PWwULHYC6ftxzplao6y
    smallcheck-1.2.1.1-7Imxv6ojngGCKa3xTj6JwK
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5.2-LuORlaNFDij9Zxtd2vz1bQ

haddock-interfaces:
    /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
